@@ -4,9 +4,11 @@ A modern, type-safe Python SDK for the DevRev API.
 """
 
 from devrev.client import AsyncDevRevClient, DevRevClient
-from devrev.config import DevRevConfig, configure, get_config
+from devrev.config import APIVersion, DevRevConfig, configure, get_config
 from devrev.exceptions import (
     AuthenticationError,
+    BetaAPIRequiredError,
+    CircuitBreakerError,
     ConfigurationError,
     ConflictError,
     DevRevError,
@@ -19,8 +21,15 @@ from devrev.exceptions import (
     TimeoutError,
     ValidationError,
 )
+from devrev.utils.http import (
+    CircuitBreakerConfig,
+    CircuitState,
+    ConnectionPoolConfig,
+    TimeoutConfig,
+)
+from devrev.utils.logging import JSONFormatter, configure_logging
 
-__version__ = "0.1.0"
+__version__ = "2.0.0"
 __all__ = [
     # Version
     "__version__",
@@ -31,6 +40,15 @@ __all__ = [
     "DevRevConfig",
     "get_config",
     "configure",
+    "APIVersion",
+    # HTTP Configuration
+    "TimeoutConfig",
+    "ConnectionPoolConfig",
+    "CircuitBreakerConfig",
+    "CircuitState",
+    # Logging
+    "configure_logging",
+    "JSONFormatter",
     # Exceptions
     "DevRevError",
     "AuthenticationError",
@@ -44,4 +62,6 @@ __all__ = [
     "ConfigurationError",
     "TimeoutError",
     "NetworkError",
+    "CircuitBreakerError",
+    "BetaAPIRequiredError",
 ]
